@@ -1,6 +1,7 @@
-#  Copyright (c) 1997-2018
-#  Ewgenij Gawrilow, Michael Joswig (Technische Universitaet Berlin, Germany)
-#  http://www.polymake.org
+#  Copyright (c) 1997-2020
+#  Ewgenij Gawrilow, Michael Joswig, and the polymake team
+#  Technische Universität Berlin, Germany
+#  https://polymake.org
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the
@@ -27,13 +28,14 @@ use vars qw(@conf_vars);
 BEGIN {
    # variables used in the configuration files and ninja rules
 
-   @conf_vars=qw( CC CXX CFLAGS CXXFLAGS ARCHFLAGS CsharedFLAGS CXXOPT CXXDEBUG CXXCOV CXXSANITIZE
+   @conf_vars=qw( CC CXX CCACHE CCWRAPPER
+                  CFLAGS CXXFLAGS ARCHFLAGS CsharedFLAGS CXXOPT CXXDEBUG CXXCOV CXXSANITIZE
                   CflagsSuppressWarnings
-                  GCCversion ICCversion CLANGversion CPPStd AppleClang
+                  GCCversion ICCversion CLANGversion CPPStd XcodeVersion
                   LDFLAGS LDsharedFLAGS LDcallableFLAGS LDsonameFLAGS LIBS
-                  LIBXML2_CFLAGS LIBXML2_LIBS ExternalHeaders
+                  ExternalHeaders
                   Arch FinkBase BrewBase BundledExts BuildModes
-                  InstallTop InstallArch InstallBin InstallInc InstallLib InstallDoc DESTDIR );
+                  InstallTop InstallArch InstallBin InstallInc InstallLib DESTDIR );
 }
 
 use vars map { "\$$_" } @conf_vars;
@@ -187,7 +189,7 @@ sub retrieve_config_command_line {
    local $_;
    if ($config_file =~ /\.ninja$/) {
       while (<$conf>) {
-         s{^\s*configure\.command[ \t]*=[ \t]*(?:\S+/configure(?=\s))?}{} and last;
+         s{^\s*configure\.command[ \t]*=(?:[ \t]*\S+/configure(?=\s))?}{} and last;
       }
       unless ($_) {
          die <<"---";
@@ -237,7 +239,7 @@ sub v_cmp($$) {
 }
 ###############################################################################################
 
-my $autonomous=!exists &Polymake::Tempfile::new;
+my $autonomous = !exists &Polymake::Tempdir::new;
 my $tempdir;
 
 sub get_tempdir {
@@ -331,12 +333,12 @@ sub add_build_modes {
 }
 ##############################################################################
 sub create_build_trees {
-   my ($buildroot, @options)=@_;
+   my ($root, $builddir, @options) = @_;
 
    # create a dummy target list, it will automatically be regenerated later
-   unless (-f "$buildroot/targets.ninja") {
-      open my $targ, ">", "$buildroot/targets.ninja"
-        or die "can't create $buildroot/targets.ninja: $!\n";
+   unless (-f "$builddir/targets.ninja" && (stat _)[9] >= (stat "$root/support/generate_ninja_targets.pl")[9]) {
+      open my $targ, ">", "$builddir/targets.ninja"
+        or die "can't create $builddir/targets.ninja: $!\n";
       print $targ <<'---';
 build all: phony
 build install: phony
@@ -346,17 +348,18 @@ build install: phony
 
    # create output directories for all supported build modes
    foreach my $mode ($BuildModes =~ /(\S+)/g) {
-      create_build_mode_subtree($buildroot, $mode);
-      write_build_ninja_file($buildroot, $mode, "build.ninja", @options);
+      create_build_mode_subtree($builddir, $mode);
+      write_build_ninja_file($builddir, $mode, "build.ninja", @options);
    }
 }
 #######################################################################
 sub create_build_mode_subtree {
-   my ($buildroot, $mode)=@_;
-   my $path="$buildroot/$mode";
+   my ($builddir, $mode) = @_;
+   my $path = "$builddir/$mode";
    if (-d $path) {
       # remove the build timestamp in order to enforce a rebuild at the next polymake start
-      unlink "$path/.apps.built";
+      # also remove old ninja logs and deps, if any: they are now living upstairs
+      unlink "$path/.apps.built", "$path/.ninja_deps", "$path/.ninja_log";
    } else {
       File::Path::make_path($path);
    }
@@ -366,7 +369,7 @@ sub create_build_mode_subtree {
 }
 #######################################################################
 sub write_build_ninja_file {
-   my ($buildroot, $mode, $filename, %options)=@_;
+   my ($builddir, $mode, $filename, %options) = @_;
 
    my @sanitize_flags;
    if ($mode eq "San") {
@@ -379,17 +382,18 @@ sub write_build_ninja_file {
       }
    }
 
-   open my $conf, ">", "$buildroot/$mode/$filename"
-     or die "can't create $buildroot/$mode/$filename: $!\n";
+   open my $conf, ">", "$builddir/$mode/$filename"
+     or die "can't create $builddir/$mode/$filename: $!\n";
 
-   my $include_list=$options{include};
-   my $depends=$include_list ? join(" ", @$include_list) : '${config.file}';
+   my $include_list = $options{include};
+   my $depends = $include_list ? join(" ", @$include_list) : '${config.file}';
 
    print $conf <<"---";
-buildroot=$buildroot
+builddir=$builddir
 buildmode=$mode
-builddir=\${buildroot}/\${buildmode}
-config.file=\${buildroot}/config.ninja
+buildtop=\${builddir}/\${buildmode}
+build.file=$filename
+config.file=\${builddir}/config.ninja
 ---
    if ($include_list) {
       print $conf <<"---";
@@ -408,19 +412,20 @@ include \${config.file}
    if ($options{perlxpath}) {
       print $conf <<"---";
 perlxpath=$options{perlxpath}
-include \${buildroot}/\${perlxpath}/config.ninja
+include \${builddir}/\${perlxpath}/config.ninja
 ---
    }
    print $conf $options{addvars}, <<"---";
 include \${root}/support/rules.ninja
 CmodeFLAGS=\${C${mode}FLAGS}
 CexternModeFLAGS=\${Cextern${mode}FLAGS}
+CmodeCACHE=\${C${mode}CACHE}
 LDmodeFLAGS=\${LD${mode}FLAGS}
 
-include \${buildroot}/targets.ninja
+include \${builddir}/targets.ninja
 
 # should rerun the target generation if any of the included files changes
-build $filename: phony | $depends \${buildroot}/targets.ninja
+build \${build.file}: phony | $depends \${builddir}/targets.ninja
 ---
 
    close $conf;
@@ -430,31 +435,20 @@ build $filename: phony | $depends \${buildroot}/targets.ninja
 # translate apple xcode to clang versions
 # some of the versions can be found here:
 # https://en.wikipedia.org/wiki/Xcode#Toolchain_versions
-sub clang_ver {
-   my $ver = shift;
-   return $ver unless defined($AppleClang);
-   # earlier versions are too old
-   if (v_cmp($ver,"4.6") < 0) {
-      return "3.1";
-   } elsif (v_cmp($ver,"5.0") < 0) {
-      return "3.2";
-   } elsif (v_cmp($ver,"5.1") < 0) {
-      return "3.3";
-   } elsif (v_cmp($ver,"6.0") < 0) {
-      return "3.4";
-   } elsif (v_cmp($ver,"6.3") < 0) {
-      return "3.5";
-   } elsif (v_cmp($ver,"7.0") < 0) {
-      return "3.6";
-   } elsif (v_cmp($ver,"7.3") < 0) {
-      return "3.7";
-   } elsif (v_cmp($ver,"8.0") < 0) {
-      return "3.8";
-   } elsif (v_cmp($ver,"8.0") >= 0) {
-      return "3.9";
-   } else {
-      die "invalid apple clang version string";
-   }
+sub xcode2clang_version {
+   my $ver = eval "v$XcodeVersion";
+   return "8.0" if $ver ge v11.0;
+   return "7.0" if $ver ge v10.2;
+   return "6.0" if $ver ge v10.0;
+   return "5.0" if $ver ge v9.3;
+   return "4.0" if $ver ge v9.0;
+   return "3.9" if $ver ge v8.0;
+   return "3.8" if $ver ge v7.3;
+   return "3.7" if $ver ge v7.0;
+   return "3.6" if $ver ge v6.3;
+   return "3.5" if $ver ge v6.0;
+   return "3.4" if $ver ge v5.1;
+   die "Apple Xcode version is too old, minimal required version is 5.1\n";
 }
 
 1
